---
name: Suggest a module
about: Suggest a new module for kiara
title: ''
labels: ''
assignees: ''

---

**Module description**
A description of the module, this will be copied into the actual module later on, so make sure you explain the module purpose with kiara users in mind. Use a short one-sentence overview as the first paragraph, then use as many paragraphs as you need to explain the module purpose and what it does.

**Inputs**
List all the inputs this module would need, along with their types, a short description, and whether they are required or should have default values. It can be assumed that a graph will always be an input, so you can skip that.

**Outupts**
List all the outputs this module would produce, along with their types and a short description of what they are.

**Example code**
If you have example code how to do what you are proposing to do, copy and paste it here.
